# baseballdc
Baseball Data Center

example request: 
baseballdc_request_player = {
	'data_source': 'BASEBALL_REFERENCE',
	'query_params': {
        'scope': 'INDIVIDUAL_PLAYER',
        'table': 'Standard Batting',
        'first_name': 'Miguel',
        'last_name': "Cabrera"
	}
}